==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/eventhub/kotlin/inputs/NWRuleSetIpRulesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.eventhub.kotlin.inputs

import com.pulumi.azurenative.eventhub.inputs.NWRuleSetIpRulesArgs.builder
import com.pulumi.azurenative.eventhub.kotlin.enums.NetworkRuleIPAction
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The response from the List namespace operation.
 * @property action The IP Filter Action
 * @property ipMask IP Mask
 */
public data class NWRuleSetIpRulesArgs(
    public val action: Output<Either<String, NetworkRuleIPAction>>? = null,
    public val ipMask: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.eventhub.inputs.NWRuleSetIpRulesArgs> {
    override fun toJava(): com.pulumi.azurenative.eventhub.inputs.NWRuleSetIpRulesArgs =
        com.pulumi.azurenative.eventhub.inputs.NWRuleSetIpRulesArgs.builder()
            .action(
                action?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .ipMask(ipMask?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [NWRuleSetIpRulesArgs].
 */
@PulumiTagMarker
public class NWRuleSetIpRulesArgsBuilder internal constructor() {
    private var action: Output<Either<String, NetworkRuleIPAction>>? = null

    private var ipMask: Output<String>? = null

    /**
     * @param value The IP Filter Action
     */
    @JvmName("mikygkxvhrvxcgdt")
    public suspend fun action(`value`: Output<Either<String, NetworkRuleIPAction>>) {
        this.action = value
    }

    /**
     * @param value IP Mask
     */
    @JvmName("fpwujsjvbjdtempp")
    public suspend fun ipMask(`value`: Output<String>) {
        this.ipMask = value
    }

    /**
     * @param value The IP Filter Action
     */
    @JvmName("ckblvhnkcksjjigr")
    public suspend fun action(`value`: Either<String, NetworkRuleIPAction>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value The IP Filter Action
     */
    @JvmName("ddatpfceocymwgnr")
    public fun action(`value`: String) {
        val toBeMapped = Either.ofLeft<String, NetworkRuleIPAction>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value The IP Filter Action
     */
    @JvmName("vlblywbochogfyio")
    public fun action(`value`: NetworkRuleIPAction) {
        val toBeMapped = Either.ofRight<String, NetworkRuleIPAction>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value IP Mask
     */
    @JvmName("dagyolgeibbgvqtt")
    public suspend fun ipMask(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ipMask = mapped
    }

    internal fun build(): NWRuleSetIpRulesArgs = NWRuleSetIpRulesArgs(
        action = action,
        ipMask = ipMask,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/eventhub/kotlin/inputs/NWRuleSetIpRulesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.eventhub.kotlin.inputs

import com.pulumi.azurenative.eventhub.inputs.NWRuleSetIpRulesArgs.builder
import com.pulumi.azurenative.eventhub.kotlin.enums.NetworkRuleIPAction
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The response from the List namespace operation.
 * @property action The IP Filter Action
 * @property ipMask IP Mask
 */
public data class NWRuleSetIpRulesArgs(
    public val action: Output<Either<String, NetworkRuleIPAction>>? = null,
    public val ipMask: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.eventhub.inputs.NWRuleSetIpRulesArgs> {
    override fun toJava(): com.pulumi.azurenative.eventhub.inputs.NWRuleSetIpRulesArgs =
        com.pulumi.azurenative.eventhub.inputs.NWRuleSetIpRulesArgs.builder()
            .action(
                action?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .ipMask(ipMask?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [NWRuleSetIpRulesArgs].
 */
@PulumiTagMarker
public class NWRuleSetIpRulesArgsBuilder internal constructor() {
    private var action: Output<Either<String, NetworkRuleIPAction>>? = null

    private var ipMask: Output<String>? = null

    /**
     * @param value The IP Filter Action
     */
    @JvmName("hopglesdmuxhagij")
    public suspend fun action(`value`: Output<Either<String, NetworkRuleIPAction>>) {
        this.action = value
    }

    /**
     * @param value IP Mask
     */
    @JvmName("qvqrwhmwoyhaqosq")
    public suspend fun ipMask(`value`: Output<String>) {
        this.ipMask = value
    }

    /**
     * @param value The IP Filter Action
     */
    @JvmName("srfioawyodtnwxcn")
    public suspend fun action(`value`: Either<String, NetworkRuleIPAction>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value The IP Filter Action
     */
    @JvmName("udmfkicfxfamhmhn")
    public fun action(`value`: String) {
        val toBeMapped = Either.ofLeft<String, NetworkRuleIPAction>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value The IP Filter Action
     */
    @JvmName("eihxwxwjaxxsryjv")
    public fun action(`value`: NetworkRuleIPAction) {
        val toBeMapped = Either.ofRight<String, NetworkRuleIPAction>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value IP Mask
     */
    @JvmName("dxbctsqbcpasndjx")
    public suspend fun ipMask(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ipMask = mapped
    }

    internal fun build(): NWRuleSetIpRulesArgs = NWRuleSetIpRulesArgs(
        action = action,
        ipMask = ipMask,
    )
}
